@@ -115,8 +115,7 @@ def write_result_to_csv(output_file, sheet_list_origin, separate_sheet=False, ex
 
     try:
         sheet_list = copy.deepcopy(sheet_list_origin)
-        is_not_null, sheet_list = remove_empty_sheet(sheet_list)
-        if is_not_null:
+        if sheet_list:
             output_files = []
             output_dir = os.path.dirname(output_file)
             Path(output_dir).mkdir(parents=True, exist_ok=True)
@@ -160,8 +159,7 @@ def write_result_to_excel(out_file_name, sheet_list, extended_header={}):
     error_msg = ""
 
     try:
-        is_not_null, sheet_list = remove_empty_sheet(sheet_list)
-        if is_not_null:
+        if sheet_list:
             output_dir = os.path.dirname(out_file_name)
             Path(output_dir).mkdir(parents=True, exist_ok=True)
 
@@ -196,15 +194,13 @@ def create_worksheet(workbook, sheet_name, header_row):
     return worksheet
 
 
-def merge_excels(find_excel_dir, final_out, csv=True):
+def merge_excels(find_excel_dir, final_out):
     success = True
     msg = ""
-    output_files = []
     FIND_EXTENSION = '.xlsx'
     added_sheet_names = []
     try:
         files = os.listdir(find_excel_dir)
-        out_dir = os.path.dirname(final_out)
 
         if len([name for name in files if name.endswith(FIND_EXTENSION)]) > 0:
             writer = pd.ExcelWriter(final_out)
@@ -220,19 +216,13 @@ def merge_excels(find_excel_dir, final_out, csv=True):
                         sheet_name_to_copy = f"{f_short_name}_{sheet_name}"
                         df_excel = pd.read_excel(
                             file, sheet_name=sheet_name, engine='openpyxl')
-                        if csv:
-                            csv_file = os.path.join(out_dir, f"{sheet_name_to_copy}.csv")
-                            df_excel.to_csv(csv_file, index=False)
-                            output_files.append(csv_file)
                         if sheet_name not in added_sheet_names:
                             sheet_name_to_copy = sheet_name
                         df_excel.to_excel(writer, sheet_name_to_copy,
                                           index=False)
             writer.save()
-            output_files.append(final_out)
     except Exception as ex:
         msg = str(ex)
         success = False
-    if success:
-        msg = ",".join(output_files)
+
     return success, msg
